<?php

namespace Thinkpool;

use Thinkpool\Utilities;
use Thinkpool\SettingsApiExtended;

/**
 * 
 * @author Nezam Uddin
 */
class ProbahoMain
{

    private $settings_api;

    // Basic settings data
    private $basic_settings;

    // Transactional settings data
    private $transactional_settings;

    // User sync settings
    private $user_sync_settings;

    // woocommerce sync settings
    private $woocommerce_sync_settings;

    // api client object
    private ApiClient $api_client;

    // transactional mail object
    private $transactional_mail;

    // User sync object
    private $user_sync;

    //site domain
    private $site_url;

    private $site_name;

    public function __construct()
    {
        $this->settings_api = new SettingsApiExtended();
        add_action('admin_init', array($this, 'probaho_admin_init'));
        add_action('admin_menu', array($this, 'probaho_admin_menu'));

        // Retreive user data from wp_options table
        $this->get_user_settings_data();

        if (isset($this->basic_settings['api_key'])) {
            $this->api_client = new ApiClient($this->basic_settings['api_key']);
        }
        if (isset($this->transactional_settings['enable_transactional']) && $this->transactional_settings['enable_transactional'] == 'on') {
            $this->transactional_mail = new TransactionalEmail($this->transactional_settings, $this->api_client);
        }

        if (isset($this->user_sync_settings['enable_user_sync']) && $this->user_sync_settings['enable_user_sync'] == 'on') {
            $this->user_sync = new UserSync($this->user_sync_settings, $this->api_client);
        }

        $this->site_url = parse_url(get_bloginfo('wpurl'));
        $this->site_name = get_bloginfo('name');
    }

    function probaho_admin_init()
    {
        //set the settings
        $this->settings_api->set_sections($this->get_settings_sections());
        $this->settings_api->set_fields($this->get_settings_fields());

        //initialize settings
        $this->settings_api->admin_init();

        // Register probaho.js
        $this->register_probaho_scripts();
    }

    function probaho_admin_menu()
    {
        add_menu_page('Probaho Settings Page', 'Probaho', 'delete_posts', 'probaho-wp-connect', array($this, 'plugin_page'), 'dashicons-email-alt');
    }

    function get_settings_sections()
    {
        $sections = array(
            array(
                'id'    => 'probaho_basics',
                'title' => __('Basic Settings', 'probaho'),
                'desc'  => __('Connct your site with Probaho', 'probaho')
            ),
            array(
                'id'    => 'probaho_user_sync',
                'title' => __('User Sync', 'probaho'),
                'desc'  => __('Sync your site users with Probaho list', 'probaho')
            ),
            array(
                'id'    => 'probaho_transactional',
                'title' => __('Transactional Email', 'probaho'),
                'desc'  => __('Send this site\'s email via Probaho', 'probaho')
            ),
            array(
                'id'    => 'probaho_woocommerce',
                'title' => __('WooCommerce Sync', 'probaho'),
                'desc'  => __('Under construction', 'probaho'),
                
            )
        );
        return $sections;
    }

    /**
     * Returns all the settings fields
     *
     * @return array settings fields
     */
    function get_settings_fields()
    {
        $settings_fields = array(
            'probaho_basics' => array(
                array(
                    'name'              => 'api_key',
                    'label'             => __('Probaho API Key', 'probaho'),
                    'desc'              => __('Get your API key <a href="https://app.probaho.com.bd/customer/api-keys/index" target="_blank">here</a>', 'probaho'),
                    'placeholder'       => __('Insert API key from your Probaho Dashboard', 'probaho'),
                    'type'              => 'text',
                    'default'           => '',
                    'sanitize_callback' => 'sanitize_text_field'
                )
            ),
            'probaho_transactional' => array(
                array(
                    'name'  => 'enable_transactional',
                    'label' => __('Enable Transactional Email', 'probaho'),
                    'desc'  => __('Check this to route all your site\'s email using Probaho', 'probaho'),
                    'type'  => 'checkbox'
                ),
                array(
                    'name'              => 'sender_name',
                    'label'             => __('Sender name', 'probaho'),
                    'placeholder'       => __('Sender name to be shown in email', 'probaho'),
                    'type'              => 'text',
                    'default'           => $this->site_name,
                    'sanitize_callback' => 'sanitize_text_field'
                ),
                array(
                    'name'              => 'sender_email',
                    'label'             => __('Sender email', 'probaho'),
                    'desc'              => __('Sending domain must be <strong>' . $this->site_url['host'] . '</strong>', 'probaho'),
                    'placeholder'       => __('Sender name to be shown in email', 'probaho'),
                    'type'              => 'email',
                    'default'           => 'info@' . $this->site_url['host'],
                    'class'             => 'sender-email'
                ),
                array(
                    'name'  => 'edit_transactional_template',
                    'label' => __('Customize default template', 'probaho'),
                    'desc'  => __('Tick to enable editing default template below', 'probaho'),
                    'type'  => 'checkbox'
                ),
                array(
                    'name'              => 'transactional_template',
                    'label'             => __('Default Template', 'probaho'),
                    'desc'              => __(' Required: %sitename%, %message%, %footer% | <a href="https://probaho.com.bd/user-guide" target="_blank">Help</a>'),
                    'placeholder'       => __('Insert your own template, remember to add default tags', 'probaho'),
                    'type'              => 'textarea',
                    'default'           => Utilities::probaho_get_default_html()
                )
            ),
            'probaho_user_sync' => array(
                array(
                    'name'  => 'enable_user_sync',
                    'label' => __('Enable User Sync', 'probaho'),
                    'desc'  => __('Tick to sync your site users with a Probaho List', 'probaho'),
                    'type'  => 'checkbox'
                ),
                array(
                    'name'              => 'user_sync_list',
                    'label'             => __('Probaho List for User Sync', 'probaho'),
                    'desc'              => __('Click <a href="https://app.probaho.com.bd/customer/lists/index" target="_blank">here</a> to see all your Probaho Lists', 'probaho'),
                    'placeholder'       => __('Put your desired Probaho list uid here', 'probaho'),
                    'type'              => 'text',
                    'default'           => '',
                    'sanitize_callback' => 'sanitize_text_field'
                ),
                array(
                    'name'              => 'name_tag',
                    'label'             => __('Subscriber\'s Name Tag Mapping', 'probaho'),
                    'desc'              => __('If you have custmized default FNAME tag, put the new tag here', 'probaho'),
                    'placeholder'       => __('Subscriber\'s name tag in uppercase ', 'probaho'),
                    'type'              => 'text',
                    'default'           => 'FNAME',
                    'sanitize_callback' => 'sanitize_text_field'
                )
            )
        );

        return $settings_fields;
    }

    function plugin_page()
    {
        echo '<div class="wrap">
            <h1>Probaho Settings Page</h1>';

        $this->settings_api->show_navigation();
        $this->settings_api->show_forms();

        echo '</div>';
    }

    /**
     * Get all the pages
     *
     * @return array page names with key value pairs
     */
    function get_pages()
    {
        $pages = get_pages();
        $pages_options = array();
        if ($pages) {
            foreach ($pages as $page) {
                $pages_options[$page->ID] = $page->post_title;
            }
        }

        return $pages_options;
    }

    function register_probaho_scripts()
    {
        wp_enqueue_script('probaho-js', plugins_url('js/probaho.js', __DIR__));
        wp_enqueue_style('probaho-css', plugins_url('css/probaho.css', __DIR__));
    }

    function get_user_settings_data()
    {
        $this->basic_settings = get_option('probaho_basics');
        $this->transactional_settings = get_option('probaho_transactional');
        $this->user_sync_settings = get_option('probaho_user_sync');
        $this->woocommerce_sync_settings = get_option('probaho_woocommerce');
    }
}
